OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan niet schrijven naar de \"config\" directory!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de de config directory",
    "See %s" : "Zie %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dit kan hersteld worden door de webserver %sschrijfrechten te geven op de de config directory%s",
    "Sample configuration detected" : "Voorbeeldconfiguratie gevonden",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Blijkbaar is de voorbeeldconfiguratie gekopieerd. Dit kan uw installatie beschadigen en wordt niet dan ook ondersteund. Lees de documentatie voordat u wijzigingen aan config.php doorvoert",
    "PHP %s or higher is required." : "PHP %s of hoger vereist.",
    "PHP with a version lower than %s is required." : "PHP met een versie lager dan %s is vereist.",
    "%sbit or higher PHP required." : "%sbit of hogere PHP vereist.",
    "Following databases are supported: %s" : "De volgende databases worden ondersteund: %s",
    "The command line tool %s could not be found" : "Commandoregel tool %s is niet gevonden",
    "The library %s is not available." : "Library %s is niet beschikbaar.",
    "Library %s with a version higher than %s is required - available version %s." : "Library %s met een versienummer hoger dan %s is vereist - beschikbare versie %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Library %s met een versienummer lager dan %s is vereist - beschikbare versie %s.",
    "Following platforms are supported: %s" : "De volgende platformen worden ondersteund: %s",
    "ownCloud %s or higher is required." : "ownCloud %s of hoger vereist.",
    "ownCloud %s or lower is required." : "ownCloud %s of lager vereist.",
    "Unknown filetype" : "Onbekend bestandsformaat",
    "Invalid image" : "Ongeldige afbeelding",
    "Avatar image is not square" : "Avatarafbeelding is niet vierkant",
    "today" : "vandaag",
    "yesterday" : "gisteren",
    "_%n day ago_::_%n days ago_" : ["%n dag geleden","%n dagen geleden"],
    "last month" : "vorige maand",
    "_%n month ago_::_%n months ago_" : ["%n maand geleden","%n maanden geleden"],
    "last year" : "vorig jaar",
    "_%n year ago_::_%n years ago_" : ["%n jaar geleden","%n jaar geleden"],
    "_%n hour ago_::_%n hours ago_" : ["%n uur geleden","%n uur geleden"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuut geleden","%n minuten geleden"],
    "seconds ago" : "seconden geleden",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met id: %s bestaat niet. Activeer het in uw apps instellingen, of neem contact op met uw beheerder.",
    "Builtin" : "Ingebouwd",
    "None" : "Geen",
    "Username and password" : "Gebruikersnaam en wachtwoord",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
    "Empty filename is not allowed" : "Een lege bestandsnaam is niet toegestaan",
    "Dot files are not allowed" : "Punt bestanden zijn niet toegestaan",
    "4-byte characters are not supported in file names" : "4-byte tekens in bestandsnamen worden niet ondersteund",
    "File name is a reserved word" : "Bestandsnaam is een gereserveerd woord",
    "File name contains at least one invalid character" : "De bestandsnaam bevat ten minste één verboden teken",
    "File name is too long" : "De bestandsnaam is te lang",
    "App directory already exists" : "App directory bestaat al",
    "Can't create app folder. Please fix permissions. %s" : "Kan de app map niet aanmaken, Herstel de permissies. %s",
    "Archive does not contain a directory named %s" : "Archief bevat geen directory genaamd %s",
    "No source specified when installing app" : "Geen bron opgegeven bij installatie van de app",
    "No href specified when installing app from http" : "Geen href opgegeven bij installeren van de app vanaf http",
    "No path specified when installing app from local file" : "Geen pad opgegeven bij installeren van de app vanaf een lokaal bestand",
    "Archives of type %s are not supported" : "Archiefbestanden van type %s niet ondersteund",
    "Failed to open archive when installing app" : "Kon archiefbestand bij installatie van de app niet openen",
    "App does not provide an info.xml file" : "De app heeft geen info.xml bestand",
    "App cannot be installed because appinfo file cannot be read." : "App kan niet worden geïnstalleerd, omdat appinfo bestand niet gelezen kan worden.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Handtekening kon niet worden geverifieerd. Nee contact op met de ontwikkelaar van de app en check uw beheerscherm.",
    "App can't be installed because of not allowed code in the App" : "De app kan niet worden geïnstalleerd wegens onjuiste code in de app",
    "App can't be installed because it is not compatible with this version of ownCloud" : "De app kan niet worden geïnstalleerd, omdat die niet compatible is met deze versie van ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "De app kan niet worden geïnstalleerd, omdat het de <shipped>true</shipped> tag bevat die niet is toegestaan voor niet gepubliceerde apps",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "De app kan niet worden geïnstalleerd, omdat de versie in info.xml niet dezelfde is als de versie zoals die in de app store staat vermeld",
    "Apps" : "Apps",
    "General" : "Algemeen",
    "Storage" : "Opslaglimiet",
    "Security" : "Beveiliging",
    "Encryption" : "Versleuteling",
    "Workflows & Tags" : "Workflows & Tags",
    "Sharing" : "Delen",
    "Search" : "Zoeken",
    "Updates" : "Updates",
    "Help & Tips" : "Help & Tips",
    "Additional" : "Extra",
    "%s enter the database username and name." : "%s voer de database gebruikersnaam en naam in .",
    "%s enter the database username." : "%s opgeven database gebruikersnaam.",
    "%s enter the database name." : "%s opgeven databasenaam.",
    "%s you may not use dots in the database name" : "%s er mogen geen puntjes in de databasenaam voorkomen",
    "Oracle connection could not be established" : "Er kon geen verbinding met Oracle worden bereikt",
    "Oracle username and/or password not valid" : "Oracle gebruikersnaam en/of wachtwoord ongeldig",
    "DB Error: \"%s\"" : "DB Fout: \"%s\"",
    "Offending command was: \"%s\"" : "Onjuiste commande was: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Geef of een bestaand account op of het beheerdersaccount.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Onjuiste commando was: \"%s\", naam: %s, wachtwoord: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL gebruikersnaam en/of wachtwoord ongeldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OSX wordt niet ondersteund en %s zal niet goed werken op dit platform. Gebruik het op uw eigen risico!",
    "For the best results, please consider using a GNU/Linux server instead." : "Voor het beste resultaat adviseren wij het gebruik van een GNU/Linux server.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Het lijkt erop dat deze %s versie draait in een 32 bits PHP omgeving en dat open_basedir is geconfigureerd in php.ini. Dat zal leiden tot problemen met bestanden groter dan 4 GB en wordt dus sterk afgeraden.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Verwijder de open_basedir instelling in php.ini of schakel over op de 64bit PHP.",
    "Set an admin username." : "Stel de gebruikersnaam van de beheerder in.",
    "Set an admin password." : "Stel een beheerderswachtwoord in.",
    "Can't create or write into the data directory %s" : "Kan niets creëren of wegschrijven in datadirectory %s",
    "Invalid Federated Cloud ID" : "Ongeldige Federated Cloud ID",
    "%s shared »%s« with you" : "%s deelde »%s« met u",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Delen van %s is mislukt, omdat de share-backend niet toestaat om type %i te delen",
    "Sharing %s failed, because the file does not exist" : "Delen van %s is mislukt, omdat het bestand niet bestaat",
    "You are not allowed to share %s" : "U bent niet bevoegd om %s te delen",
    "Sharing %s failed, because you can not share with yourself" : "Delen van %s is mislukt, omdat iemand niet met zichzelf kan delen",
    "Sharing %s failed, because the user %s does not exist" : "Delen van %s is mislukt, omdat gebruiker %s niet bestaat",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Delen van %s is mislukt, omdat gebruiker %s geen lid is van een groep waar %s lid van is",
    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met gebruiker %s",
    "Sharing %s failed, because the group %s does not exist" : "Delen van %s is mislukt, omdat groep %s niet bestaat",
    "Sharing %s failed, because %s is not a member of the group %s" : "Delen van %s is mislukt, omdat %s geen lid is van groep %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "U moet een wachtwoord verstrekken om een openbare koppeling te maken, alleen beschermde links zijn toegestaan",
    "Sharing %s failed, because sharing with links is not allowed" : "Delen van %s is mislukt, omdat het delen met links niet is toegestaan",
    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar.",
    "Share type %s is not valid for %s" : "Delen van type %s is niet geldig voor %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Instellen van de permissies voor %s is mislukt, omdat de permissies hoger zijn dan de aan %s toegekende permissies",
    "Setting permissions for %s failed, because the item was not found" : "Instellen van de permissies voor %s is mislukt, omdat het object niet is gevonden",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kon vervaldatum niet instellen. Shares kunnen niet langer dan %s vervallen na het moment van delen",
    "Cannot set expiration date. Expiration date is in the past" : "Kon vervaldatum niet instellen. De vervaldatum ligt in het verleden",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Kon vervaldatum niet weghalen. Shares moeten een vervaldatum hebben.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Het share-backend %s moet de OCP\\Share_Backend interface implementeren",
    "Sharing backend %s not found" : "Het share-backend %s is niet gevonden",
    "Sharing backend for %s not found" : "Het share-backend voor %s is niet gevonden",
    "Sharing failed, because the user %s is the original sharer" : "Delen mislukt, omdat gebruiker %s de originele deler is",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Delen van %s is mislukt, omdat de rechten de aan %s toegekende autorisaties overschrijden",
    "Sharing %s failed, because resharing is not allowed" : "Delen van %s is mislukt, omdat her-delen niet is toegestaan",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delen van %s is mislukt, omdat de share-backend voor %s de bron niet kon vinden",
    "Sharing %s failed, because the file could not be found in the file cache" : "Delen van %s is mislukt, omdat het bestand niet in de bestandscache kon worden gevonden",
    "Cannot increase permissions of %s" : "Kan de rechten van %s niet verruimen",
    "Files can't be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijderrechten",
    "Files can't be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met creatie rechten",
    "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
    "Cannot set expiration date more than %s days in the future" : "Kan vervaldatum niet verder dan %s dagen in de toekomst instellen",
    "Could not find category \"%s\"" : "Kon categorie \"%s\" niet vinden",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Alleen de volgende tekens zijn toegestaan in een gebruikersnaam: \"a-z\", \"A-Z\", \"0-9\", en \"_.@-\"",
    "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
    "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of eind",
    "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
    "The username is already being used" : "De gebruikersnaam bestaat al",
    "Login canceled by app" : "Inloggen geannuleerd door app",
    "User disabled" : "Gebruiker gedeactiveerd",
    "Help" : "Help",
    "Settings" : "Instellingen",
    "Users" : "Gebruikers",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %s",
    "web services under your control" : "Webdiensten in eigen beheer",
    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
    "Can't read file" : "Kan bestand niet lezen",
    "Application is not enabled" : "De applicatie is niet actief",
    "Authentication error" : "Authenticatie fout",
    "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
    "Unknown user" : "Onbekende gebruiker",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Geen database drivers (sqlite, mysql of postgres) geïnstalleerd.",
    "Cannot write into \"config\" directory" : "Kan niet schrijven naar de \"config\" directory",
    "Cannot write into \"apps\" directory" : "Kan niet schrijven naar de \"apps\" directory",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te %s geven op de appsdirectory %s of door de appstore te deactiveren in het configbestand.",
    "Cannot create \"data\" directory" : "Kan de \"data\" directory niet aanmaken",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dit kan worden hersteld door <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> de webserver schrijfrechten te geven tot de hoofddirectory</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dit kan hersteld worden door de webserver schrijfrechten te %s geven op de hoofddirectory %s.",
    "Setting locale to %s failed" : "Instellen taal op %s mislukte",
    "Please install one of these locales on your system and restart your webserver." : "Installeer één van de talen op uw systeem en herstart uw webserver.",
    "Please ask your server administrator to install the module." : "Vraag uw beheerder om de module te installeren.",
    "PHP module %s not installed." : "PHP module %s niet geïnstalleerd.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP instelling \"%s\" staat niet op \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Het in php.ini bijstellen hiervan laat ownCloud weer werken",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is ingesteld op \"%s\" in plaats van op de verwachte waarde \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Om dit op te lossen stel <code>mbstring.func_overload</code> in op <code>0</code> in uw php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "De laagste toegestane libxml2 versie is 2.7.0. Momenteel is %s is geïnstalleerd.",
    "To fix this issue update your libxml2 version and restart your web server." : "Om dit te herstellen, moet u de libxml2 versie bijwerken en uw webserver herstarten.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is blijkbaar zo ingesteld dat inline doc blokken worden gestript. Hierdoor worden verschillende kernmodules onbruikbaar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar worden ze nog steeds als ontbrekend aangegeven?",
    "Please ask your server administrator to restart the web server." : "Vraag uw beheerder de webserver opnieuw op te starten.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vereist",
    "Please upgrade your database version" : "Werk uw database versie bij",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de permissies in 0770 zodat de directory niet door anderen bekeken kan worden.",
    "Your Data directory is readable by other users" : "Uw datadirectory is leesbaar voor andere gebruikers",
    "Your Data directory must be an absolute path" : "Uw datadirectory moet een absoluut pad hebben",
    "Check the value of \"datadirectory\" in your configuration" : "Controleer de waarde van \"datadirectory\" in uw configuratie",
    "Your Data directory  is invalid" : "Uw datadirectory is ongeldig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifieer dat de data directory een bestand \".ocdata\" in de hoofdmap heeft.",
    "Could not obtain lock type %d on \"%s\"." : "Kon geen lock type %d krijgen op \"%s\".",
    "Storage unauthorized. %s" : "Opslag niet toegestaan. %s",
    "Storage incomplete configuration. %s" : "Incomplete opslagconfiguratie. %s",
    "Storage connection error. %s" : "Opslagverbindingsfout. %s",
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage connection timeout. %s" : "Opslagverbinding time-out. %s",
    "A safe home for all your data" : "Een veilig thuis voor al uw gegevens",
    "User Authentication" : "Gebruiker authenticatie",
    "File cannot be read" : "Bestand kan niet worden gelezen",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s wordt niet ondersteund en %s zal niet goed werken op dit platform. Gebruik het op uw eigen risico!",
    "Imprint" : "afdruk",
    "__language_name__" : "Nederlands",
    "Privacy Policy" : "Privacybeleid"
},
"nplurals=2; plural=(n != 1);");
